Learn R Programming

bayeslist (version 0.0.1.5)

london: The 2017 London List Experiment

Description

This dataset is the 2017 London list experiment on voter turnout fielded via online YouGov survey of a sample of 3189 Greater Londoners.The main question reads as follows: The next question deals with the recent general election on 8th June. Here is a list of four (five) things that some people did and some people did not do during the election campaign or on Election Day. Please say how many of these things you did. Here are the four (five) things: (1) Discussed the election with family and friends; (2) (Voted in the election); (3) Criticised a politician on social media; (4) Avoided watching the leaders debates; (5) Put up a poster for a political party in my window or garden. How many of these things did you do? The second item in bracket is the sensitive item. In addition to the above list, there is a direct question asking about turnout: Talking with people about the recent general election on 8th June, we have found that a lot of people didn't manage to vote. How about you, did you manage to vote in the general election?

Arguments

Format

A data frame containing the following 18 variables for 3189 observations.

IDintegerRespondent ID number.
ageintegerRespondent age in years.
agegrpfactorRespondent age group.
genderfactorYouGov panel measure of gender.
social_gradefactorYouGov panel measure of respondent social grade.
qualfactorMeasure of highest educational qualification from YouGov panel.
validationfactorfactorDetailed measure of turnout validation outcome for respondent.
validturnoutintegerSummary measure of true respondent turnout.
directintegerResponse to direct turnout question asked of list experiment control group.
baselineTurnoutintegerResponse to baseline direct turnout question after the election.
listTreatintegerIndicator for list experiment treatment group.
listCountintegerReported item count for list experiment question.
qtimenumericTime taken to answer list experiment question, in seconds.
recallfirstcharacterRespondent recall of first item from list question. Open text response.
recalllastcharacterRespondent recall of last item from list question. Open text response.
recallfirst.hand.correctfactorDid respondent correctly recall first list experiment item?
recalllast.hand.correctfactorDid respondent correctly recall last list experiment item?
comfortnumericHow comfortable do you feel revealing whether you did/did not vote in last election?

References

Kuhn, P. M., & Vivyan, N. (2021). The misreporting trade-off between list experiments and direct questions in practice: Partition validation evidence from two countries. Political Analysis, 1-22.