plot_coef.bayeslist: Make coefficient plots for a 'bayeslist' object

View source: R/plotfun.R

plot_coef.bayeslistR Documentation

Make coefficient plots for a bayeslist object

Description

plot_coef.bayeslist is used to produce coefficient plots from a bayeslist object.

Usage

plot_coef.bayeslist(object, ...)

Arguments

object

A bayeslist object from running the main function bayeslist.

...

Additional parameters to be passed to stan_plot.

Value

None.


bayeslist documentation built on Jan. 18, 2026, 5:06 p.m.