plot_prevalence.bayeslist is used to produce plots of prevalence from a bayeslist object from the main function bayeslist.
plot_prevalence.bayeslist(
object,
covariate_names = NULL,
only_prev = FALSE,
xlim = NULL,
inverse = FALSE,
digit = 3,
...
)None.
A bayeslist object from running the main function bayeslist.
Names of covariates.
Indicating whether only prevalence will be plotted. The default is FALSE.
Limits of x-axis.
Indicating whether prevalence should be calculated in the reverse order. The default is FALSE.
Digit number to be displayed.
Additional parameters to be passed.