plot_trace.bayeslist: Trace plots for bayeslist

View source: R/plotfun.R

plot_trace.bayeslistR Documentation

Trace plots for bayeslist

Description

plot_trace.bayeslist is used to produce trace plots from a bayeslist object from the main function bayeslist.

Usage

plot_trace.bayeslist(object, ...)

Arguments

object

A bayeslist object from running the main function bayeslist.

...

Additional parameters to be passed to traceplot.

Value

None.


bayeslist documentation built on Jan. 18, 2026, 5:06 p.m.