Learn R Programming

bayeslist (version 0.0.1.5)

print.bayeslist: Print returns from a bayeslist object

Description

General print function for bayeslist objects, which dispatches the chosen type of printing to the corresponding function.

Usage

# S3 method for bayeslist
print(x, type = "text", ...)

Value

None.

Arguments

x

A bayeslist object to be printed.

type

Character string giving the type of printing, such as "text", "mcmc", "coef".

...

Additional arguments to be passed to print functions (check the See Also section).

See Also

print_text.bayeslist, print_mcmc.bayeslist, print_coef.bayeslist.