Learn R Programming

bayeslist (version 0.0.1.5)

print_mcmc.bayeslist: Print convergence diagnostics from a bayeslist object

Description

print_mcmc.bayeslist prints a number of diagnostics about the convergence of a bayeslist objects.

Usage

print_mcmc.bayeslist(object, ...)

Value

None.

Arguments

object

A bayeslist object.

...

Additional arguments to be passed to the print function.