coef.bayeslist: Extract coefficients from a bayeslist object
Description
Create a table of coefficient results from a bayeslist object.
Usage
# S3 method for bayeslist
coef(object, ...)
Value
A table of coefficients with their corresponding lower and upper bounds.
Arguments
- object
A bayeslist object from running the main function bayeslist.
- ...
Further arguments to be passed according to coef.