bayeslist objectGeneral print function for bayeslist objects, which dispatches the chosen type
of printing to the corresponding function.
# S3 method for bayeslist
print(x, type = "text", ...)None.
A bayeslist object to be printed.
Character string giving the type of printing, such as
"text", "mcmc", "coef".
Additional arguments to be passed to print functions (check the See Also section).
print_text.bayeslist, print_mcmc.bayeslist, print_coef.bayeslist.